[4.0] 8d3e492 VCC default vcl -> builtin vcl renames.

Dag Haavi Finstad daghf at varnish-software.com
Tue Apr 1 15:09:55 CEST 2014


commit 8d3e4924058aa4f5ca90ea7c917fb183bd42a6a9
Author: Dag Haavi Finstad <daghf at varnish-software.com>
Date:   Fri Mar 28 13:01:33 2014 +0100

    VCC default vcl -> builtin vcl renames.

diff --git a/bin/varnishd/mgt/mgt_vcc.c b/bin/varnishd/mgt/mgt_vcc.c
index 09e4eb4..2c2ffd9 100644
--- a/bin/varnishd/mgt/mgt_vcc.c
+++ b/bin/varnishd/mgt/mgt_vcc.c
@@ -488,7 +488,7 @@ mgt_vcc_init(void)
 
 	vcc = VCC_New();
 	AN(vcc);
-	VCC_Default_VCL(vcc, builtin_vcl);
+	VCC_Builtin_VCL(vcc, builtin_vcl);
 	AZ(atexit(mgt_vcc_atexit));
 }
 
diff --git a/include/libvcc.h b/include/libvcc.h
index 5c50c34..6b16252 100644
--- a/include/libvcc.h
+++ b/include/libvcc.h
@@ -31,7 +31,7 @@
 struct vcc;
 
 struct vcc *VCC_New(void);
-void VCC_Default_VCL(struct vcc *, const char *str);
+void VCC_Builtin_VCL(struct vcc *, const char *str);
 void VCC_VCL_dir(struct vcc *, const char *str);
 void VCC_VMOD_dir(struct vcc *, const char *str);
 void VCC_Err_Unref(struct vcc *tl, unsigned u);
diff --git a/lib/libvcc/vcc_compile.h b/lib/libvcc/vcc_compile.h
index bdfda05..128916b 100644
--- a/lib/libvcc/vcc_compile.h
+++ b/lib/libvcc/vcc_compile.h
@@ -160,7 +160,7 @@ struct vcc {
 #define VCC_MAGIC		0x24ad719d
 
 	/* Parameter/Template section */
-	char			*default_vcl;
+	char			*builtin_vcl;
 	char			*vcl_dir;
 	char			*vmod_dir;
 



More information about the varnish-commit mailing list
diff --git a/lib/libvcc/vcc_compile.c b/lib/libvcc/vcc_compile.c
index 91ea4c9..81a7620 100644
--- a/lib/libvcc/vcc_compile.c
+++ b/lib/libvcc/vcc_compile.c
@@ -489,7 +489,7 @@ vcc_NewVcc(const struct vcc *tl0)
 	ALLOC_OBJ(tl, VCC_MAGIC);
 	AN(tl);
 	if (tl0 != NULL) {
-		REPLACE(tl->default_vcl, tl0->default_vcl);
+		REPLACE(tl->builtin_vcl, tl0->builtin_vcl);
 		REPLACE(tl->vcl_dir, tl0->vcl_dir);
 		REPLACE(tl->vmod_dir, tl0->vmod_dir);
 		tl->vars = tl0->vars;
@@ -612,8 +612,8 @@ vcc_CompileSource(const struct vcc *tl0, struct vsb *sb, struct source *sp)
 	if (tl->err)
 		return (vcc_DestroyTokenList(tl, NULL));
 
-	/* Register and lex the default VCL */
-	sp = vcc_new_source(tl->default_vcl, NULL, "Default");
+	/* Register and lex the builtin VCL */
+	sp = vcc_new_source(tl->builtin_vcl, NULL, "Builtin");
 	assert(sp != NULL);
 	VTAILQ_INSERT_TAIL(&tl->sources, sp, list);
 	sp->idx = tl->nsources++;
@@ -736,15 +736,15 @@ VCC_New(void)
 }
 
 /*--------------------------------------------------------------------
  * Configure default VCL source code
  */
 
 void
-VCC_Default_VCL(struct vcc *tl, const char *str)
+VCC_Builtin_VCL(struct vcc *tl, const char *str)
 {
 
 	CHECK_OBJ_NOTNULL(tl, VCC_MAGIC);
-	REPLACE(tl->default_vcl, str);
+	REPLACE(tl->builtin_vcl, str);
 }
 
 /*--------------------------------------------------------------------
@@ -736,15 +736,15 @@ VCC_New(void)
 
 /*--------------------------------------------------------------------
- * Configure default VCL source code
+ * Configure builtin VCL source code
  */
 